==> ds-bootstrap-0.0.21.tgz: package/esm/Widgets/OptionsCheck/OptionsCheck.js <==
import React from "react";
import { TransTitle, Trans, beautifyKey, extractValue, memo, updateValue } from "@ui-schema/ui-schema";
import { List, Map } from "immutable";
import { useUID } from "react-uid";
import { ValidityHelperText } from "../../Component/LocaleHelperText/LocaleHelperText";

const CheckInput = ({
  currentValue,
  onChange,
  label,
  value,
  classForm,
  classLabel,
  classFormControl
}) => {
  const uid = useUID();
  return /*#__PURE__*/React.createElement("div", {
    className: classForm
  }, /*#__PURE__*/React.createElement("input", {
    id: 'uis-' + uid,
    type: "checkbox",
    className: classFormControl,
    value: value,
    checked: currentValue,
    onChange: onChange
  }), /*#__PURE__*/React.createElement("label", {
    className: classLabel,
    htmlFor: 'uis-' + uid
  }, label));
};

const OptionsCheckValue = extractValue(memo(({
  enumVal,
  storeKeys,
  value,
  onChange,
  classLabel,
  classFormControl,
  classForm,
  schema,
  required,
  type
}) => enumVal ? enumVal.map(enum_name => {
  const currentValue = value && value.contains && typeof value.contains(enum_name) !== 'undefined' ? value.contains(enum_name) : false;
  return /*#__PURE__*/React.createElement(CheckInput, {
    key: enum_name,
    value: enum_name,
    classForm: classForm,
    classLabel: classLabel,
    classFormControl: classFormControl,
    currentValue: currentValue,
    onChange: () => {
      if (currentValue) {
        onChange(updateValue(storeKeys, value.delete(value.indexOf(enum_name)), required, type));
      } else {
        onChange(updateValue(storeKeys, value ? value.push(enum_name) : List([]).push(enum_name), required, type));
      }
    },
    label: /*#__PURE__*/React.createElement(Trans, {
      schema: schema.get('t'),
      text: storeKeys.insert(0, 'widget').concat(List(['enum', enum_name])).join('.'),
      context: Map({
        'relative': List(['enum', enum_name])
      }),
      fallback: beautifyKey(enum_name)
    })
  });
}).valueSeq() : null));

const OptionsCheck = ({
  schema,
  storeKeys,
  showValidity,
  errors,
  ownKey,
  required
}) => {
  const enumVal = schema.get('enum');
  if (!enumVal) return null;
  let classForm = ["custom-control", "custom-checkbox"];
  let classLabel = ["custom-control-label", "text-light"];
  let classFormControl = ["custom-control-input", "checkbox-inline"];

  if (showValidity && errors.size) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.size) {
    classForm.push('was-validated');
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/React.createElement(OptionsCheckValue, {
    required: required,
    type: schema.get('type'),
    classForm: classForm.join(' '),
    classLabel: classLabel.join(' '),
    classFormControl: classFormControl.join(' '),
    enumVal: enumVal,
    storeKeys: storeKeys,
    schema: schema
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { OptionsCheck };

==> ds-bootstrap-0.1.0.tgz: package/esm/Widgets/OptionsCheck/OptionsCheck.js <==
import React from "react";
import { TransTitle, Trans, beautifyKey, extractValue, memo, updateValue } from "@ui-schema/ui-schema";
import { List, Map } from "immutable";
import { useUID } from "react-uid";
import { ValidityHelperText } from "../../Component/LocaleHelperText/LocaleHelperText";

const CheckInput = ({
  currentValue,
  onChange,
  label,
  value,
  classForm,
  classLabel,
  classFormControl
}) => {
  const uid = useUID();
  return /*#__PURE__*/React.createElement("div", {
    className: classForm
  }, /*#__PURE__*/React.createElement("input", {
    id: 'uis-' + uid,
    type: "checkbox",
    className: classFormControl,
    value: value,
    checked: currentValue,
    onChange: onChange
  }), /*#__PURE__*/React.createElement("label", {
    className: classLabel,
    htmlFor: 'uis-' + uid
  }, label));
};

const OptionsCheckValue = extractValue(memo(({
  enumVal,
  storeKeys,
  value,
  onChange,
  classLabel,
  classFormControl,
  classForm,
  schema,
  required,
  type
}) => enumVal ? enumVal.map(enum_name => {
  const currentValue = value && value.contains && typeof value.contains(enum_name) !== 'undefined' ? value.contains(enum_name) : false;
  return /*#__PURE__*/React.createElement(CheckInput, {
    key: enum_name,
    value: enum_name,
    classForm: classForm,
    classLabel: classLabel,
    classFormControl: classFormControl,
    currentValue: currentValue,
    onChange: () => {
      if (currentValue) {
        onChange(updateValue(storeKeys, value.delete(value.indexOf(enum_name)), required, type));
      } else {
        onChange(updateValue(storeKeys, value ? value.push(enum_name) : List([]).push(enum_name), required, type));
      }
    },
    label: /*#__PURE__*/React.createElement(Trans, {
      schema: schema.get('t'),
      text: storeKeys.insert(0, 'widget').concat(List(['enum', enum_name])).join('.'),
      context: Map({
        'relative': List(['enum', enum_name])
      }),
      fallback: beautifyKey(enum_name)
    })
  });
}).valueSeq() : null));

const OptionsCheck = ({
  schema,
  storeKeys,
  showValidity,
  errors,
  ownKey,
  required
}) => {
  const enumVal = schema.get('enum');
  if (!enumVal) return null;
  let classForm = ["custom-control", "custom-checkbox"];
  let classLabel = ["custom-control-label", "text-light"];
  let classFormControl = ["custom-control-input", "checkbox-inline"];

  if (showValidity && errors.hasError()) {
    classFormControl.push('is-invalid');
  }

  if (showValidity && !errors.hasError()) {
    classForm.push('was-validated');
  }

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(TransTitle, {
    schema: schema,
    storeKeys: storeKeys,
    ownKey: ownKey
  }), /*#__PURE__*/React.createElement(OptionsCheckValue, {
    required: required,
    type: schema.get('type'),
    classForm: classForm.join(' '),
    classLabel: classLabel.join(' '),
    classFormControl: classFormControl.join(' '),
    enumVal: enumVal,
    storeKeys: storeKeys,
    schema: schema
  }), /*#__PURE__*/React.createElement(ValidityHelperText, {
    errors: errors,
    showValidity: showValidity,
    schema: schema
  }));
};

export { OptionsCheck };
